.. |gmsh_link| raw:: html gmsh .. |fc-oogmsh_link| raw:: html fc_oogmsh .. |fc-mayavi4mesh_link| raw:: html fc_mayavi4mesh .. |fc-meshtools_link| raw:: html fc_meshtools .. |python-mayavi_link| raw:: html Python and Mayavi .. |python_link| raw:: html www.python.org .. |canopy_link| raw:: html Canopy .. |anaconda_link| raw:: html Anaconda .. |mayavi_link| raw:: html Mayavi .. |miniconda_link| raw:: html Miniconda